package Perl6::Pod::Lib;

#$Id$

=pod

=head1 NAME

Perl6::Pod::Lib - set of extensions for Perl6::Pod

=head1 SYNOPSIS

    use Perl6::Pod::Lib;

=head1 DESCRIPTION

=cut

$Perl6::Pod::Lib::VERSION = '0.02';

1;
__END__


=head1 SEE ALSO

L<http://perlcabal.org/syn/S26.html>

=head1 AUTHOR

Zahatski Aliaksandr, <zag@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010 by Zahatski Aliaksandr

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

=cut

